@@ -12,3 +12,5 @@ from .fimi.fimi_reader import FimiReader
 from .fimi.fimi_writer import FimiWriter
 from .matlab.matlab_reader import MatlabReader
 from .matlab.matlab_writer import MatlabWriter
+from .cex.cex_reader import CexReader
+from .cex.cex_writer import CexWriter
