@@ -1,10 +1,14 @@
+import math
+
 from convertme import ReaderInterface, Dataset
+from bitarray import bitarray
 
 
 class FimiReader(ReaderInterface):
-
     def read(self, file):
         max_attribute = 0
+        min_attribute = math.inf
+
         rows = []
 
         for line in file:
@@ -16,12 +20,17 @@ class FimiReader(ReaderInterface):
                 attribute = int(value)
                 row_attributes.append(attribute)
                 max_attribute = max(attribute, max_attribute)
+                min_attribute = min(attribute, min_attribute)
 
             rows.append(row_attributes)
 
-        bools = [[True if i in row else False for i in range(max_attribute + 1)]
-                 for row in rows]
+        bools = [
+            bitarray([True if i in row else False for i in range(min_attribute, max_attribute + 1)])
+            for row in rows
+        ]
 
-        return Dataset(list(map(str, range(len(bools)))),
-                       list(map(str, range(max_attribute + 1))),
-                       bools)
+        return Dataset(
+            list(map(str, range(len(bools)))),
+            list(map(str, range(min_attribute, max_attribute + 1))),
+            bools,
+        )
